`frobenius.norm` <-
function(A)
    {
    sqrt(sum(A^2))
    }

